import { FormKitTypeDefinition } from '@formkit/core'
import {
  actions,
  submitInput,
  forms,
  disablesChildren,
  createSection,
} from '@formkit/inputs'
import { messages } from '../sections/messages'

const formInput = createSection('form', () => ({
  $el: 'form',
  bind: '$attrs',
  meta: {
    autoAnimate: true,
  },
  attrs: {
    id: '$id',
    name: '$node.name',
    onSubmit: '$handlers.submit',
    'data-loading': '$state.loading || undefined',
  },
}))

/**
 * Input definition for a form.
 * @public
 */
export const form: FormKitTypeDefinition = {
  /**
   * The actual schema of the input, or a function that returns the schema.
   */
  schema: formInput(
    '$slots.default',
    messages(),
    actions(submitInput())
  ),
  /**
   * The type of node, can be a list, group, or input.
   */
  type: 'group',
  /**
   * An array of extra props to accept for this input.
   */
  props: [
    'actions',
    'submit',
    'submitLabel',
    'submitAttrs',
    'submitBehavior',
    'incompleteMessage',
  ],
  /**
   * Additional features that should be added to your input
   */
  features: [forms, disablesChildren],
  /**
   * The key used to memoize the schema.
   */
  // schemaMemoKey: 'rorzq1rsrf',
}
